@@ -47,8 +47,10 @@
 #define CUSTOM_HEADER_RC	"customheaderrc"
 #define DISPLAY_HEADER_RC	"dispheaderrc"
 #define MENU_RC			"menurc"
+#define ACTIONS_RC		"actionsrc"
 #define COMMAND_HISTORY		"command_history"
 #define TEMPLATE_DIR		"templates"
+#define TMP_DIR			"tmp"
 #define NEWSGROUP_LIST		".newsgroup_list"
 #define ADDRESS_BOOK		"addressbook.xml"
 #define MANUAL_HTML_INDEX	"sylpheed.html"
