@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2001 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2002 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,6 +74,8 @@ struct _MainWindow
 	GtkWidget *vbox;
 	GtkWidget *menubar;
 
+	GtkItemFactory *menu_factory;
+
 	/* toolbar */
 	GtkWidget *handlebox;
 	GtkWidget *toolbar;
@@ -131,6 +133,8 @@ void main_window_set_account_menu	(GList		*account_list);
 void main_window_separation_change	(MainWindow	*mainwin,
 					 SeparateType	 type);
 
+void main_window_toggle_message_view	(MainWindow	*mainwin);
+
 void main_window_get_size		(MainWindow	*mainwin);
 void main_window_get_position		(MainWindow	*mainwin);
 
