@@ -51,6 +51,7 @@
 		fclose(tmp_fp); \
 		fclose(mbox_fp); \
 		unlink(tmp_file); \
+		g_free(tmp_file); \
 		return -1; \
 	} \
 }
@@ -108,6 +109,7 @@ gint proc_mbox(FolderItem *dest, const gchar *mbox, GHashTable *folder_table)
 			FILE_OP_ERROR(tmp_file, "fopen");
 			g_warning(_("can't open temporary file\n"));
 			fclose(mbox_fp);
+			g_free(tmp_file);
 			return -1;
 		}
 		if (change_file_mode_rw(tmp_fp, tmp_file) < 0)
@@ -194,6 +196,7 @@ gint proc_mbox(FolderItem *dest, const gchar *mbox, GHashTable *folder_table)
 			g_warning(_("can't write to temporary file\n"));
 			fclose(mbox_fp);
 			unlink(tmp_file);
+			g_free(tmp_file);
 			return -1;
 		}
 
@@ -216,12 +219,14 @@ gint proc_mbox(FolderItem *dest, const gchar *mbox, GHashTable *folder_table)
 		if (folder_item_add_msg(dropfolder, tmp_file, TRUE) < 0) {
 			fclose(mbox_fp);
 			unlink(tmp_file);
+			g_free(tmp_file);
 			return -1;
 		}
 
 		msgs++;
 	} while (from_line[0] != '\0');
 
+	g_free(tmp_file);
 	fclose(mbox_fp);
 	debug_print(_("%d messages found.\n"), msgs);
 
@@ -348,7 +353,7 @@ gint unlock_mbox(const gchar *base, gint fd, LockType type)
 
 gint copy_mbox(const gchar *src, const gchar *dest)
 {
-	return copy_file(src, dest);
+	return copy_file(src, dest, TRUE);
 }
 
 void empty_mbox(const gchar *mbox)
@@ -388,7 +393,7 @@ gint export_to_mbox(FolderItem *src, const gchar *mbox)
 		return -1;
 	}
 
-	mlist = src->folder->get_msg_list(src->folder, src, TRUE);
+	mlist = folder_item_get_msg_list(src, TRUE);
 
 	for (cur = mlist; cur != NULL; cur = cur->next) {
 		msginfo = (MsgInfo *)cur->data;
