@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2001 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2002 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ void prefs_read_config(PrefParam *param, const gchar *label,
 	prefs_set_default(param);
 
 	rcpath = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, rcfile, NULL);
-	if ((fp = fopen(rcpath, "r")) == NULL) {
+	if ((fp = fopen(rcpath, "rb")) == NULL) {
 		if (ENOENT != errno) FILE_OP_ERROR(rcpath, "fopen");
 		g_free(rcpath);
 		return;
@@ -159,7 +159,7 @@ void prefs_save_config(PrefParam *param, const gchar *label,
 	g_return_if_fail(rcfile != NULL);
 
 	rcpath = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, rcfile, NULL);
-	if ((orig_fp = fopen(rcpath, "r")) == NULL) {
+	if ((orig_fp = fopen(rcpath, "rb")) == NULL) {
 		if (ENOENT != errno) FILE_OP_ERROR(rcpath, "fopen");
 	}
 
@@ -267,7 +267,7 @@ PrefFile *prefs_write_open(const gchar *path)
 	g_return_val_if_fail(path != NULL, NULL);
 
 	tmppath = g_strconcat(path, ".tmp", NULL);
-	if ((fp = fopen(tmppath, "w")) == NULL) {
+	if ((fp = fopen(tmppath, "wb")) == NULL) {
 		FILE_OP_ERROR(tmppath, "fopen");
 		g_free(tmppath);
 		return NULL;
@@ -479,6 +479,16 @@ void prefs_dialog_create(PrefsDialog *dialog)
 	dialog->apply_btn  = apply_btn;
 }
 
+void prefs_dialog_destroy(PrefsDialog *dialog)
+{
+	gtk_widget_destroy(dialog->window);
+	dialog->window     = NULL;
+	dialog->notebook   = NULL;
+	dialog->ok_btn     = NULL;
+	dialog->cancel_btn = NULL;
+	dialog->apply_btn  = NULL;
+}
+
 void prefs_button_toggled(GtkToggleButton *toggle_btn, GtkWidget *widget)
 {
 	gboolean is_active;
