@@ -328,14 +328,12 @@ void procmsg_set_flags(GSList *mlist, FolderItem *item)
 	g_hash_table_destroy(mark_table);
 }
 
-gint procmsg_get_last_num_in_cache(GSList *mlist)
+gint procmsg_get_last_num_in_msg_list(GSList *mlist)
 {
 	GSList *cur;
 	MsgInfo *msginfo;
 	gint last = 0;
 
-	if (mlist == NULL) return 0;
-
 	for (cur = mlist; cur != NULL; cur = cur->next) {
 		msginfo = (MsgInfo *)cur->data;
 		if (msginfo && msginfo->msgnum > last)
@@ -503,6 +501,10 @@ static GHashTable *procmsg_read_mark_file(const gchar *folder)
 	while (fread(&num, sizeof(num), 1, fp) == 1) {
 		if (fread(&perm_flags, sizeof(perm_flags), 1, fp) != 1) break;
 
+		flags = g_hash_table_lookup(mark_table, GUINT_TO_POINTER(num));
+		if (flags != NULL)
+			g_free(flags);
+
 		flags = g_new0(MsgFlags, 1);
 		flags->perm_flags = perm_flags;
 
@@ -854,7 +856,7 @@ gint procmsg_save_to_outbox(FolderItem *outbox, const gchar *file,
 	FILE *fp;
 	MsgFlags flag = {0, 0};
 
-	debug_print(_("saving sent message...\n"));
+	debug_print("saving sent message...\n");
 
 	if (!outbox)
 		outbox = folder_get_default_outbox();
@@ -883,13 +885,19 @@ gint procmsg_save_to_outbox(FolderItem *outbox, const gchar *file,
 			fputs(buf, outfp);
 		fclose(outfp);
 		fclose(fp);
-		Xstrdup_a(file, tmp, return -1);
-	}
 
-	folder_item_scan(outbox);
-	if ((num = folder_item_add_msg(outbox, file, FALSE)) < 0) {
-		g_warning(_("can't save message\n"));
-		return -1;
+		folder_item_scan(outbox);
+		if ((num = folder_item_add_msg(outbox, tmp, TRUE)) < 0) {
+			g_warning("can't save message\n");
+			unlink(tmp);
+			return -1;
+		}
+	} else {
+		folder_item_scan(outbox);
+		if ((num = folder_item_add_msg(outbox, file, FALSE)) < 0) {
+			g_warning("can't save message\n");
+			return -1;
+		}
 	}
 
 	procmsg_add_flags(outbox, num, flag);
